==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/XtResource.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;


/**
 * @author zhangyu
 * @version 1.0, 2017/5/25
 * @description
 */
@Table(name = "XT_RESOURCE")
public class XtResource implements Serializable {
    @Id
    private String resourceId;
    private String resourceName;
    private String resourceUrl;
    private String parResourceId;
    private String groupId;
    private String defaultShow;
    private String orderNo;
    private String description;
    private String resourceCode;

    //冗余字段
    private String groupName;
    private String groupNo;
    private String xtButtons;

    private List<XtResource> childResources;

    public String getResourceId() {
        return resourceId;
    }

    public void setResourceId(String resourceId) {
        this.resourceId = resourceId;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public String getResourceUrl() {
        return resourceUrl;
    }

    public void setResourceUrl(String resourceUrl) {
        this.resourceUrl = resourceUrl;
    }

    public String getParResourceId() {
        return parResourceId;
    }

    public void setParResourceId(String parResourceId) {
        this.parResourceId = parResourceId;
    }

    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
    }

    public List<XtResource> getChildResources() {
        return childResources;
    }

    public void setChildResources(List<XtResource> childResources) {
        this.childResources = childResources;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public String getGroupNo() {
        return groupNo;
    }

    public void setGroupNo(String groupNo) {
        this.groupNo = groupNo;
    }

    public String getDefaultShow() {
        return defaultShow;
    }

    public void setDefaultShow(String defaultShow) {
        this.defaultShow = defaultShow;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getXtButtons() {
        return xtButtons;
    }

    public void setXtButtons(String xtButtons) {
        this.xtButtons = xtButtons;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getResourceCode() {
        return resourceCode;
    }

    public void setResourceCode(String resourceCode) {
        this.resourceCode = resourceCode;
    }
}

==> realestate-supervise-common-1.1.0-20241231.014802-54-sources.jar: cn/gtmap/realestate/supervise/entity/XtResource.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.List;


/**
 * @author zhangyu
 * @version 1.0, 2017/5/25
 * @description
 */
@Table(name = "XT_RESOURCE")
public class XtResource implements Serializable {
    @Id
    private String resourceId;
    private String resourceName;
    private String resourceUrl;
    private String parResourceId;
    private String groupId;
    private String defaultShow;
    private String orderNo;
    private String description;
    private String resourceCode;
    //是否展示水印
    private String watermaker;

    //冗余字段
    private String groupName;
    private String groupNo;
    private String xtButtons;

    private List<XtResource> childResources;

    public String getResourceId() {
        return resourceId;
    }

    public void setResourceId(String resourceId) {
        this.resourceId = resourceId;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public String getResourceUrl() {
        return resourceUrl;
    }

    public void setResourceUrl(String resourceUrl) {
        this.resourceUrl = resourceUrl;
    }

    public String getParResourceId() {
        return parResourceId;
    }

    public void setParResourceId(String parResourceId) {
        this.parResourceId = parResourceId;
    }

    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
    }

    public List<XtResource> getChildResources() {
        return childResources;
    }

    public void setChildResources(List<XtResource> childResources) {
        this.childResources = childResources;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public String getGroupNo() {
        return groupNo;
    }

    public void setGroupNo(String groupNo) {
        this.groupNo = groupNo;
    }

    public String getDefaultShow() {
        return defaultShow;
    }

    public void setDefaultShow(String defaultShow) {
        this.defaultShow = defaultShow;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getXtButtons() {
        return xtButtons;
    }

    public void setXtButtons(String xtButtons) {
        this.xtButtons = xtButtons;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getResourceCode() {
        return resourceCode;
    }

    public void setResourceCode(String resourceCode) {
        this.resourceCode = resourceCode;
    }

    public String getWatermaker() {
        return watermaker;
    }

    public void setWatermaker(String watermaker) {
        this.watermaker = watermaker;
    }

    @Override
    public String toString() {
        return "XtResource{" +
            "resourceId='" + resourceId + '\'' +
            ", resourceName='" + resourceName + '\'' +
            ", resourceUrl='" + resourceUrl + '\'' +
            ", parResourceId='" + parResourceId + '\'' +
            ", groupId='" + groupId + '\'' +
            ", defaultShow='" + defaultShow + '\'' +
            ", orderNo='" + orderNo + '\'' +
            ", description='" + description + '\'' +
            ", resourceCode='" + resourceCode + '\'' +
            ", groupName='" + groupName + '\'' +
            ", groupNo='" + groupNo + '\'' +
            ", xtButtons='" + xtButtons + '\'' +
            ", watermaker='" + watermaker + '\'' +
            ", childResources=" + childResources +
            '}';
    }


}
